@@ -62,6 +62,7 @@ import com.openexchange.caldav.Patches;
 import com.openexchange.caldav.mixins.DefaultAlarmVeventDate;
 import com.openexchange.caldav.mixins.DefaultAlarmVeventDatetime;
 import com.openexchange.caldav.mixins.SupportedCalendarComponentSet;
+import com.openexchange.caldav.mixins.SupportedCalendarComponentSets;
 import com.openexchange.exception.OXException;
 import com.openexchange.folderstorage.UserizedFolder;
 import com.openexchange.groupware.calendar.CalendarCollectionService;
@@ -97,8 +98,12 @@ public class AppointmentCollection extends CalDAVFolderCollection<Appointment> {
     public AppointmentCollection(GroupwareCaldavFactory factory, WebdavPath url, UserizedFolder folder, int order) throws OXException {
         super(factory, url, folder, order);
         this.factory = factory;
-        includeProperties(new SupportedCalendarComponentSet(SupportedCalendarComponentSet.VEVENT),
-            new DefaultAlarmVeventDate(), new DefaultAlarmVeventDatetime());
+        includeProperties(
+            new SupportedCalendarComponentSet(SupportedCalendarComponentSet.VEVENT),
+            new SupportedCalendarComponentSets(SupportedCalendarComponentSets.VEVENT),
+            new DefaultAlarmVeventDate(),
+            new DefaultAlarmVeventDatetime()
+        );
     }
 
     public List<Appointment> getAppointments() throws OXException {
