@@ -85,6 +85,7 @@ import com.openexchange.webdav.action.WebdavExistsAction;
 import com.openexchange.webdav.action.WebdavGetAction;
 import com.openexchange.webdav.action.WebdavHeadAction;
 import com.openexchange.webdav.action.WebdavIfAction;
+import com.openexchange.webdav.action.WebdavIfMatchAction;
 import com.openexchange.webdav.action.WebdavLockAction;
 import com.openexchange.webdav.action.WebdavLogAction;
 import com.openexchange.webdav.action.WebdavMkcolAction;
@@ -180,7 +181,7 @@ public class CaldavPerformer implements SessionHolder {
         mkcol = prepare(new WebdavMkcolAction(), true, true, new WebdavIfAction(0, true, false));
         lock = prepare(new WebdavLockAction(), true, true, new WebdavIfAction(0, true, false));
         copy = prepare(new WebdavCopyAction(factory), true, true, new WebdavExistsAction(), new WebdavIfAction(0, false, true));
-        delete = prepare(new WebdavDeleteAction(), true, true, new WebdavExistsAction(), new WebdavIfAction(0, true, false));
+        delete = prepare(new WebdavDeleteAction(), true, true, new WebdavExistsAction(), new WebdavIfMatchAction(), new WebdavIfAction(0, true, false));
         get = prepare(new WebdavGetAction(), true, false, new WebdavExistsAction(), new WebdavIfAction(0, false, false));
         head = prepare(new WebdavHeadAction(), true, true, new WebdavExistsAction(), new WebdavIfAction(0, false, false));
         post = prepare(new WebdavPostAction(factory), true, true, new WebdavIfAction(0, false, false));
@@ -192,7 +193,7 @@ public class CaldavPerformer implements SessionHolder {
         final OXWebdavMaxUploadSizeAction oxWebdavMaxUploadSize = new OXWebdavMaxUploadSizeAction();
         oxWebdavMaxUploadSize.setSessionHolder(this);
 
-        put = prepare(oxWebdavPut, false, true, oxWebdavMaxUploadSize);
+        put = prepare(oxWebdavPut, false, true, new WebdavIfMatchAction(), oxWebdavMaxUploadSize);
         trace = prepare(new WebdavTraceAction(), true, true, new WebdavIfAction(0, false, false));
 
         actions.put(Action.UNLOCK, unlock);
