@@ -56,8 +56,6 @@ import javax.servlet.http.HttpServletResponse;
 import org.apache.commons.logging.Log;
 import com.openexchange.exception.OXException;
 import com.openexchange.login.Interface;
-import com.openexchange.login.internal.LoginPerformer;
-import com.openexchange.tools.servlet.http.Tools;
 import com.openexchange.tools.session.ServerSession;
 import com.openexchange.tools.session.ServerSessionAdapter;
 import com.openexchange.tools.webdav.AllowAsteriskAsSeparatorCustomizer;
@@ -164,38 +162,9 @@ public class WebdavDirectoryServlet extends OXServlet {
         	}
         	resp.setStatus(500);
         	resp.sendError(500);
-        } finally {
-            if (mustLogOut(req)) {
-                logout(session, req, resp);
-            }
         }
     }
 
-    private void logout(final ServerSession session, final HttpServletRequest req, final HttpServletResponse resp) {
-        removeCookie(req, resp);
-        try {
-            LoginPerformer.getInstance().doLogout(session.getSessionID());
-        } catch (final OXException e) {
-            LOG.error(e.getMessage(), e);
-        }
-    }
-
-    private static final transient Tools.CookieNameMatcher COOKIE_MATCHER = new Tools.CookieNameMatcher() {
-
-        @Override
-        public boolean matches(final String cookieName) {
-            return (COOKIE_SESSIONID.equals(cookieName) || Tools.JSESSIONID_COOKIE.equals(cookieName));
-        }
-    };
-
-    private void removeCookie(final HttpServletRequest req, final HttpServletResponse resp) {
-        Tools.deleteCookies(req, resp, COOKIE_MATCHER);
-    }
-
-    private boolean mustLogOut(final HttpServletRequest req) {
-        return true;
-    }
-
     private static final LoginCustomizer ALLOW_ASTERISK = new AllowAsteriskAsSeparatorCustomizer();
 
     @Override
@@ -203,4 +172,9 @@ public class WebdavDirectoryServlet extends OXServlet {
         return ALLOW_ASTERISK;
     }
 
+    @Override
+    protected boolean useCookies() {
+        return false;
+    }
+
 }
